==> librenms-25.9.1v0.tgz: librenms/lang/zh-TW/map.php <==
<?php

return [
    'custom' => [
        'title' => [
            'edit_dialog' => '選擇要編輯的自訂地圖',
            'create' => '建立新的自訂地圖',
            'view' => ':name | 自訂地圖',
            'edit' => '編輯自訂地圖',
            'manage' => '管理自訂地圖',
        ],
        'create_map' => '新增地圖',
        'view' => [
            'loading' => '載入資料中',
            'no_devices' => '找不到裝置',
        ],
        'nodeimage' => [
            'delete' => '刪除圖片',
            'upload' => '上傳圖片',
            'name' => '圖片名稱',
            'new' => '新增圖片',
            'title' => [
                'edit' => '編輯節點圖片',
                'manage' => '管理節點圖片',
                'new' => '新增節點圖片',
            ],
        ],
        'edit' => [
            'text_font' => '文字字型',
            'text_size' => '文字大小',
            'text_color' => '文字顏色',
            'defaults' => '設定預設值',
            'bg' => [
                'title' => '設定背景',
                'background' => '背景',
                'color' => '顏色',
                'image' => '圖片',
                'map' => '地圖',
                'none' => '無',
                'clear_bg' => '清除背景',
                'clear_background' => '清除背景',
                'keep_background' => '保留背景',
                'saving' => '儲存中...',
                'save_errors' => '因下列錯誤而儲存失敗：',
                'save_error' => '儲存失敗。伺服器回傳錯誤代碼：:code',
                'save' => '儲存背景',
                'lat' => '緯度',
                'lng' => '經度',
                'zoom' => '縮放',
                'adjust_map' => '調整地圖',
                'adjust_map_finish' => '完成地圖調整',
                'as_image' => '設為圖片',
                'as_image_hint' => '將地圖設為圖片背景將會是靜態的，但可改善效能且無需連接地圖圖磚伺服器',
            ],
            'map' => [
                'settings_title' => '地圖設定',
                'selectall' => '全選',
                'name' => '名稱',
                'menu_group' => '選單群組',
                'multiselect_info' => '長按或按住 Ctrl 鍵可選擇多個節點',
                'no_group' => '無群組',
                'width' => '寬度',
                'height' => '高度',
                'alignment' => '節點對齊',
                'edgeseparation' => '連線間隔',
                'reverse' => '箭頭反向',
                'saving' => '儲存中...',
                'save_errors' => '因下列錯誤而儲存失敗：',
                'save_error' => '儲存失敗。伺服器回傳錯誤代碼：:code',
                'clone' => '複製 :name？',
                'delete' => '刪除 :name？',
                'list' => '返回地圖列表',
                'unsavedchanges' => '您有未儲存的變更。按確認以捨棄變更並返回地圖列表，或按取消返回編輯器。',
                'edit' => '編輯地圖設定',
                'rerender' => '重新繪製地圖',
                'save' => '儲存地圖',
                'legend' => [
                    'customcolours' => '自訂顏色',
                    'colour' => '顏色',
                    'colour_lower_pct' => '起始百分比',
                    'colour_down' => '裝置停機顏色',
                    'colour_invalid' => '未知百分比顏色',
                    'font_size' => '圖例文字大小',
                    'steps' => '圖例步驟',
                    'hideinvalid' => '隱藏無效值',
                    'hideoverspeed' => '隱藏 100%+',
                ],
                'legend_title' => '圖例設定',
                'legend_toggle' => '切換圖例',
                'zoom' => '平移與縮放',
                'dragnodes' => '移動節點',
                'physics' => '物理引擎',
            ],
            'node' => [
                'new' => '新增節點',
                'add' => '新增節點',
                'edit' => '編輯節點',
                'defaults_title' => '節點預設設定',
                'label' => '標籤',
                'name' => '節點名稱',
                'device_select' => '選擇裝置',
                'edit_defaults' => '編輯節點預設值',
                'map_link' => '連結到地圖',
                'map_select' => '選擇地圖...',
                'style' => '樣式',
                'style_options' => [
                    'box' => '方框',
                    'circle' => '圓形',
                    'database' => '資料庫',
                    'ellipse' => '橢圓',
                    'text' => '文字',
                    'device_image' => '裝置圖片',
                    'device_image_circle' => '裝置圖片（圓形）',
                    'diamond' => '菱形',
                    'dot' => '點',
                    'star' => '星形',
                    'triangle' => '三角形',
                    'triangle_inverted' => '倒三角形',
                    'hexagon' => '六角形',
                    'square' => '正方形',
                    'icon' => '圖示（請選擇下方）',
                ],
                'icon' => '圖示',
                'icon_options' => [
                    'server' => '伺服器',
                    'desktop' => '桌上型電腦',
                    'dish' => '衛星天線',
                    'satellite' => '衛星',
                    'wifi' => '無線網路',
                    'cloud' => '雲端',
                    'globe' => '地球',
                    'tower' => '信號塔',
                    'arrow_right' => '箭頭 - 右',
                    'arrow_left' => '箭頭 - 左',
                    'arrow_up' => '箭頭 - 上',
                    'arrow_down' => '箭頭 - 下',
                ],
                'image' => '圖片',
                'image_options' => [
                    'adc' => '應用程式交付控制器',
                    'firewall' => '防火牆',
                    'gtm' => '全域流量管理器',
                    'router' => '路由器',
                    'switch-l2' => '交換器 - L2',
                    'switch-l3' => '交換器 - L3',
                ],
                'size' => '節點大小',
                'bg_color' => '背景顏色',
                'border_color' => '邊框顏色',
            ],
            'edge' => [
                'new' => '新增連線',
                'add' => '新增連線',
                'edit' => '編輯連線',
                'defaults_title' => '連線預設設定',
                'dynamic_width' => '動態寬度',
                'fixed_width' => '固定寬度',
                'from' => '來源',
                'to' => '目標',
                'port_select' => '選擇連接埠',
                'reverse' => '反向連接埠方向',
                'edit_defaults' => '編輯連線預設值',
                'style' => '線條樣式',
                'style_options' => [
                    'dynamic' => '動態',
                    'continuous' => '連續',
                    'discrete' => '離散',
                    'diagonalCross' => '對角交叉',
                    'straightCross' => '直線交叉',
                    'horizontal' => '水平',
                    'vertical' => '垂直',
                    'curvedCW' => '順時針曲線',
                    'curvedCCW' => '逆時針曲線',
                    'cubicBezier' => '貝茲曲線',
                ],
                'show_usage_percent' => '顯示使用率百分比',
                'show_usage_bps' => '顯示流量',
                'text_align' => '文字對齊',
                'align_options' => [
                    'horizontal' => '水平',
                    'top' => '上方',
                    'middle' => '中間',
                    'bottom' => '上方',
                ],
                'label' => '標籤',
                'recenter' => '重新置中線條',
            ],
            'validate' => [
                'width_format' => '寬度必須是數字後接 px 或 %',
                'width_percent' => '寬度百分比必須介於 10 到 100 之間',
                'width_pixels' => '寬度像素必須至少 200',
                'height_format' => '高度必須是數字後接 px 或 %',
                'height_percent' => '高度百分比必須介於 10 到 100 之間',
                'height_pixels' => '高度像素必須至少 200',
            ],
        ],
        'widget' => [
            'not_found' => '未選擇地圖。請編輯小工具以選擇地圖。',
        ],
    ],
];

==> librenms-25.11.0v0.tgz: librenms/lang/zh-TW/map.php <==
<?php

return [
    'custom' => [
        'title' => [
            'edit_dialog' => '選擇要編輯的自訂地圖',
            'create' => '建立新的自訂地圖',
            'view' => ':name | 自訂地圖',
            'edit' => '編輯自訂地圖',
            'manage' => '管理自訂地圖',
        ],
        'create_map' => '新增地圖',
        'view' => [
            'loading' => '正在載入資料',
            'no_devices' => '找不到任何裝置',
            'legend' => '圖例',
            'invalid_link' => '連線中斷或未設定連線速率',
            'go_to' => '前往',
            'unknown' => '???',
        ],
        'nodeimage' => [
            'delete' => '刪除圖片',
            'upload' => '上傳圖片',
            'name' => '圖片名稱',
            'new' => '新增圖片',
            'title' => [
                'edit' => '編輯節點圖片',
                'manage' => '管理節點圖片',
                'new' => '新增節點圖片',
            ],
        ],
        'edit' => [
            'text_font' => '文字字型',
            'text_size' => '文字大小',
            'text_color' => '文字顏色',
            'defaults' => '設定為預設值',
            'bg' => [
                'title' => '設定背景',
                'background' => '背景',
                'color' => '顏色',
                'image' => '圖片',
                'map' => '地圖',
                'none' => '無',
                'clear_bg' => '清除背景',
                'clear_background' => '清除背景',
                'keep_background' => '保留背景',
                'saving' => '儲存中…',
                'save_errors' => '儲存失敗，錯誤如下：',
                'save_error' => '儲存失敗，伺服器回傳錯誤代碼：:code',
                'save' => '儲存背景',
                'lat' => '緯度',
                'lng' => '經度',
                'zoom' => '縮放',
                'adjust_map' => '調整地圖',
                'adjust_map_finish' => '完成地圖調整',
                'as_image' => '設為圖片背景',
                'as_image_hint' => '將地圖設為圖片背景會變成靜態，但效能更佳，且即使無法連線至地圖伺服器也能正常顯示。',
            ],
            'map' => [
                'settings_title' => '地圖設定',
                'selectall' => '全選',
                'name' => '名稱',
                'menu_group' => '選單群組',
                'multiselect_info' => '長按或按住 Ctrl 可多選節點',
                'no_group' => '無群組',
                'width' => '寬度',
                'height' => '高度',
                'alignment' => '節點對齊',
                'edgeseparation' => '連線間距',
                'reverse' => '反向箭頭',
                'saving' => '儲存中…',
                'save_errors' => '儲存失敗，錯誤如下：',
                'save_error' => '儲存失敗，伺服器回傳錯誤代碼：:code',
                'clone' => '要複製 :name？',
                'delete' => '要刪除 :name？',
                'list' => '返回地圖清單',
                'unsavedchanges' => '你有尚未儲存的變更。按「確認」將捨棄變更並返回地圖清單，或按「取消」繼續編輯。',
                'edit' => '編輯地圖設定',
                'rerender' => '重新繪製地圖',
                'save' => '儲存地圖',
                'legend' => [
                    'customcolours' => '自訂顏色',
                    'colour' => '顏色',
                    'colour_lower_pct' => '起始百分比',
                    'colour_down' => '裝置離線顏色',
                    'colour_invalid' => '未知百分比顏色',
                    'font_size' => '圖例文字大小',
                    'steps' => '圖例分級數',
                    'hideinvalid' => '隱藏未知',
                    'hideoverspeed' => '隱藏 100% 以上',
                ],
                'legend_title' => '圖例設定',
                'legend_toggle' => '顯示/隱藏圖例',
                'zoom' => '平移與縮放',
                'dragnodes' => '移動節點',
                'physics' => '物理引擎',
            ],
            'node' => [
                'new' => '新增節點',
                'add' => '加入節點',
                'edit' => '編輯節點',
                'defaults_title' => '節點預設設定',
                'label' => '標籤',
                'name' => '節點名稱',
                'device_select' => '選擇裝置',
                'edit_defaults' => '編輯節點預設值',
                'map_link' => '連結至地圖',
                'map_select' => '選擇地圖…',
                'style' => '樣式',
                'style_options' => [
                    'box' => '方框',
                    'circle' => '圓形',
                    'database' => '資料庫',
                    'ellipse' => '橢圓形',
                    'text' => '文字',
                    'device_image' => '裝置圖片',
                    'device_image_circle' => '裝置圖片（圓形）',
                    'diamond' => '菱形',
                    'dot' => '圓點',
                    'star' => '星形',
                    'triangle' => '三角形',
                    'triangle_inverted' => '倒三角形',
                    'hexagon' => '六邊形',
                    'square' => '正方形',
                    'icon' => '圖示（下方選擇）',
                ],
                'icon' => '圖示',
                'icon_options' => [
                    'server' => '伺服器',
                    'desktop' => '桌機',
                    'dish' => '衛星天線',
                    'satellite' => '衛星',
                    'wifi' => 'Wi-Fi',
                    'cloud' => '雲端',
                    'globe' => '地球',
                    'tower' => '通訊塔',
                    'arrow_right' => '箭頭 - 右',
                    'arrow_left' => '箭頭 - 左',
                    'arrow_up' => '箭頭 - 上',
                    'arrow_down' => '箭頭 - 下',
                ],
                'image' => '圖片',
                'image_options' => [
                    'adc' => '應用程式傳遞控制器（ADC）',
                    'firewall' => '防火牆',
                    'gtm' => '全域流量管理（GTM）',
                    'router' => '路由器',
                    'switch-l2' => '交換器 - L2',
                    'switch-l3' => '交換器 - L3',
                ],
                'size' => '節點大小',
                'bg_color' => '背景顏色',
                'border_color' => '邊框顏色',
            ],
            'edge' => [
                'new' => '新增連線',
                'add' => '加入連線',
                'edit' => '編輯連線',
                'defaults_title' => '連線預設設定',
                'dynamic_width' => '動態寬度',
                'fixed_width' => '固定寬度',
                'from' => '來源',
                'to' => '目的',
                'port_select' => '選擇通訊埠',
                'reverse' => '反轉通訊埠方向',
                'edit_defaults' => '編輯連線預設值',
                'style' => '線條樣式',
                'style_options' => [
                    'dynamic' => '動態',
                    'continuous' => '連續',
                    'discrete' => '離散',
                    'diagonalCross' => '斜向交叉',
                    'straightCross' => '直線交叉',
                    'horizontal' => '水平',
                    'vertical' => '垂直',
                    'curvedCW' => '順時針曲線',
                    'curvedCCW' => '逆時針曲線',
                    'cubicBezier' => '三次貝茲曲線',
                ],
                'show_usage_percent' => '顯示使用率 (%)',
                'show_usage_bps' => '顯示使用量 (bps)',
                'text_align' => '文字對齊',
                'align_options' => [
                    'horizontal' => '水平',
                    'top' => '上方',
                    'middle' => '置中',
                    'bottom' => '下方',
                ],
                'label' => '標籤',
                'recenter' => '連線置中',
            ],
            'validate' => [
                'width_format' => '寬度必須為數字後接 px 或 %',
                'width_percent' => '寬度百分比必須介於 10 到 100 之間',
                'width_pixels' => '寬度（像素）至少需 200',
                'height_format' => '高度必須為數字後接 px 或 %',
                'height_percent' => '高度百分比必須介於 10 到 100 之間',
                'height_pixels' => '高度（像素）至少需 200',
            ],
        ],
        'widget' => [
            'not_found' => '未選擇地圖，請編輯元件以選擇地圖。',
        ],
    ],
];
